import 'dart:convert';
import 'XLibStorage.dart';

class XLibJSon {
  static Future SaveToJSonFile(Object? value, String fileName) async {
    try {
      var jsonData = Serialize(value!);
      await XLibStorage.SaveDataFileAsync(fileName, jsonData);
    } catch (ex) {}
  }

  static Future<T?> LoadFromJSonFile<T>(String fileName, T factory(Map<String, dynamic> data)) async {
    try {
      String jsonData = await XLibStorage.ReadTextAsync(fileName);
      if (jsonData != "") {
        var value = DeserializeFromString<T>(jsonData, factory);
        return value;
      } else {
        return null;
      }
    } catch (ex) {
      return null;
    }
  }

  static Future<List<T?>?> LoadListFromJSonFile<T>(String fileName, T factory(Map<String, dynamic> data)) async {
    try {
      String jsonData = await XLibStorage.ReadTextAsync(fileName);
      if (jsonData != "") {
        Iterable list = jsonDecode(jsonData);
        var value = list.map((item) => Deserialize<T>(item, factory)).toList();

        return value;
      } else {
        return null;
      }
    } catch (ex) {
      return null;
    }
  }

  static T? DeserializeFromString<T>(String jsonStringData, T factory(Map<String, dynamic> data)) {
    try {
      if (jsonStringData != "") {
        var value = factory(jsonDecode(jsonStringData) as Map<String, dynamic>);
        return value;
      } else {
        return null;
      }
    } catch (ex) {
      return null;
    }
  }

  static T? Deserialize<T>(Map<String, dynamic>? jsonData, T factory(Map<String, dynamic> data)) {
    try {
      if (jsonData != null) {
        var value = factory(jsonData);
        return value;
      } else {
        return null;
      }
    } catch (ex) {
      return null;
    }
  }

  static String Serialize(Object value) {
    try {
      return jsonEncode(value);
    } catch (ex) {
      print(ex);
      return ex.toString();
    }
  }
}
