part of xwidgetbase;

class XTreeNode extends StatefulWidget {
  final int? level;
  final bool? expaned;
  final double? offsetLeft;
  final List<Widget>? children;
  final Color colorIcon;
  final Color colorTreeNode;
  final EdgeInsets? paddingTreeNode;

  final Widget? title;
  final Widget? leading;
  final Widget? trailing;

  final Function? titleOnTap;
  final Function? leadingOnTap;
  final Function? trailingOnTap;

  const XTreeNode({
    this.colorIcon = Colors.white,
    this.colorTreeNode = Colors.black,
    this.paddingTreeNode,
    this.level = 0,
    this.expaned = false,
    this.offsetLeft = 24.0,
    this.children = const [],
    this.title = const Text('Title'),
    this.leading = const IconButton(
      icon: Icon(Icons.star_border, color: Colors.white),
      iconSize: 16,
      onPressed: null,
    ),
    this.trailing = const IconButton(
      icon: Icon(
        Icons.expand_more,
        color: Colors.white,
      ),
      iconSize: 16,
      onPressed: null,
    ),
    this.titleOnTap,
    this.leadingOnTap,
    this.trailingOnTap,
  });

  @override
  _TreeNodeState createState() => _TreeNodeState();
}

class _TreeNodeState extends State<XTreeNode> with SingleTickerProviderStateMixin {
  bool _isExpaned = false;

  AnimationController? _rotationController;
  final Tween<double> _turnsTween = Tween<double>(begin: 0.0, end: -0.5);

  initState() {
    _isExpaned = widget.expaned!;
    _rotationController = AnimationController(
      duration: const Duration(milliseconds: 300),
      vsync: this,
    );
    super.initState();
  }

  @override
  void dispose() {
    _rotationController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final level = widget.level;
    final children = widget.children;
    final offsetLeft = widget.offsetLeft;
    final colorIcon = widget.colorIcon;
    final colorTreeNode = widget.colorTreeNode;
    final paddingTreeNode = widget.paddingTreeNode;
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        GestureDetector(
            onTap: () {
              if (widget.leadingOnTap != null && widget.leadingOnTap is Function) {
                widget.leadingOnTap!();
              }
            },
            child: Container(
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.all(Radius.circular(10)),
                  color: colorTreeNode,
                ),
                child: Padding(
                  padding: paddingTreeNode ?? const EdgeInsets.only(left: 12.0, top: 5, bottom: 5),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      GestureDetector(
                        onTap: () {
                          setState(() {
                            _isExpaned = !_isExpaned;
                            if (_isExpaned) {
                              _rotationController!.forward();
                            } else {
                              _rotationController!.reverse();
                            }
                            if (widget.trailingOnTap != null && widget.trailingOnTap is Function) {
                              widget.trailingOnTap!();
                            }
                          });
                          if (widget.leadingOnTap != null && widget.leadingOnTap is Function) {
                            widget.leadingOnTap!();
                          }
                        },
                        child: Center(
                          child: widget.leading ??
                              IconButton(
                                icon: Icon(Icons.star_border),
                                iconSize: 16,
                                onPressed: null,
                                color: colorIcon,
                              ),
                        ),
                      ),
                      SizedBox(width: 6.0),
                      Expanded(
                        child: GestureDetector(
                          onTap: () {
                            setState(() {
                              _isExpaned = !_isExpaned;
                              if (_isExpaned) {
                                _rotationController!.forward();
                              } else {
                                _rotationController!.reverse();
                              }
                              if (widget.trailingOnTap != null && widget.trailingOnTap is Function) {
                                widget.trailingOnTap!();
                              }
                            });
                            if (widget.titleOnTap != null && widget.titleOnTap is Function) {
                              widget.titleOnTap!();
                            }
                          },
                          child: widget.title ?? Container(),
                        ),
                      ),
                      SizedBox(width: 6.0),
                      Visibility(
                        visible: children!.isNotEmpty,
                        child: Center(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                _isExpaned = !_isExpaned;
                                if (_isExpaned) {
                                  _rotationController!.forward();
                                } else {
                                  _rotationController!.reverse();
                                }
                                if (widget.trailingOnTap != null && widget.trailingOnTap is Function) {
                                  widget.trailingOnTap!();
                                }
                              });
                            },
                            child: RotationTransition(
                              child: widget.trailing ??
                                  IconButton(
                                    icon: Icon(Icons.expand_more),
                                    iconSize: 16,
                                    onPressed: null,
                                    color: colorIcon,
                                  ),
                              turns: _turnsTween.animate(_rotationController!),
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ))),
        Visibility(
          visible: children.isNotEmpty && _isExpaned,
          child: Padding(
            padding: EdgeInsets.only(left: level! + 1 * offsetLeft!),
            child: Column(
              children: widget.children!,
              crossAxisAlignment: CrossAxisAlignment.start,
            ),
          ),
        ),
      ],
    );
  }
}
