part of xwidgetbase;

class XTextFormFieldLogin extends StatelessWidget {
  final String? label;
  final String? hintText;
  final String? initialValue;
  final IconData? prefixIcon;
  final Decoration? decoration;
  final ValueChanged<String>? onChanged;
  final TextInputType keyboardType;
  final Function? onFieldSubmitted;
  final Function? onSaved;
  final Function? validator;
  final FocusNode? focusNode;
  final double width;
  final Widget? suffixIcon;
  final TextInputAction textInputAction;
  final TextEditingController? controller;
  final String obscuringCharacter = '•';
  final bool obscureText;
  final bool borderVisible;

  final TextStyle? hintStyle;
  final TextStyle? styleText;
  final TextStyle? labelStyle;

  final Color? borderColor;
  final Color? colorPrefixIcon;
  final Color? colorSuffixIcon;
  final Color? colorHintText;
  final Color? colorLabel;
  final Color? colorBorder;

  final InputBorder? border;
  final InputBorder? disabledBorder;
  final InputBorder? enabledBorder;
  final InputBorder? focusedBorder;

  XTextFormFieldLogin(
      {this.label,
      this.borderColor,
      this.colorPrefixIcon,
      this.colorSuffixIcon,
      this.enabledBorder,
      this.disabledBorder,
      this.focusedBorder,
      this.borderVisible = true,
      this.border,
      this.hintText,
      this.labelStyle,
      this.colorBorder,
      this.hintStyle,
      this.styleText,
      this.prefixIcon,
      this.controller,
      this.decoration,
      this.suffixIcon,
      this.colorHintText,
      this.colorLabel,
      this.onChanged,
      this.width = 300,
      this.keyboardType = TextInputType.text,
      this.textInputAction = TextInputAction.next,
      this.onFieldSubmitted,
      this.onSaved,
      this.initialValue,
      this.validator,
      this.focusNode,
      this.obscureText = false});

  xLabelStyle() {
    return TextStyle(color: Colors.black, fontFamily: 'OpenSans', fontSize: 12);
  }

  xBoxDecorationStyle(Color? color) {
    return BoxDecoration(
        border: Border.all(
          color: color ?? Colors.white,
          width: 1,
        ),
        borderRadius: BorderRadius.all(Radius.circular(10)));
  }

  @override
  Widget build(BuildContext context) {
    return Column(crossAxisAlignment: CrossAxisAlignment.start, children: <Widget>[
      Text(label ?? "", style: xLabelStyle()),
      Container(
        width: width,
        decoration: xBoxDecorationStyle(borderColor ?? Colors.white),
        child: TextFormField(
          focusNode: focusNode,
          keyboardType: keyboardType,
          style: styleText ?? TextStyle(color: Colors.white),
          textInputAction: textInputAction,
          onFieldSubmitted: onFieldSubmitted as void Function(String)?,
          obscureText: obscureText,
          onSaved: onSaved as void Function(String?)?,
          obscuringCharacter: obscuringCharacter,
          controller: controller,
          onChanged: onChanged,
          maxLines: 1,
          initialValue: initialValue,
          validator: validator as String? Function(String?)?,
          decoration: InputDecoration(
            border: borderVisible == true ? border ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
            disabledBorder: borderVisible == true ? disabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
            enabledBorder: borderVisible == true ? enabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
            focusedBorder: borderVisible == true ? focusedBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
            prefixIcon: Icon(prefixIcon, color: colorPrefixIcon ?? Colors.white),
            hintText: hintText ?? "",
            hintStyle: hintStyle ?? XStyles.xStyTextForLabel(colorHintText ?? colorPrefixIcon ?? Colors.white),
            labelStyle: labelStyle ?? XStyles.xStyTextForLabel(colorLabel ?? colorPrefixIcon ?? Colors.white),
            suffixIcon: suffixIcon != null ? Container(width: 20, child: suffixIcon) : null,
          ),
        ),
      ),
    ]);
  }
}
